diff mbox series

[v2] contrib/: Configure git-format-patch(1) to add To: gcc-patches@gcc.gnu.org

Message ID 2bd0e0f82bf0b536a3827625d52f56e9cd27cd2e.1729176716.git.alx@kernel.org
State New
Headers show
Series [v2] contrib/: Configure git-format-patch(1) to add To: gcc-patches@gcc.gnu.org | expand

Commit Message

Alejandro Colomar Oct. 17, 2024, 2:54 p.m. UTC
Just like we already do for git-send-email(1).  In some cases, patches
are prepared with git-format-patch(1), but are sent with a different
program, or some flags to git-send-email(1) may accidentally inhibit the
configuration.  By adding the TO in the email file, we make sure that
gcc-patches@ will receive the patch.

contrib/ChangeLog:

	* gcc-git-customization.sh: Configure git-format-patch(1) to add
	'To: gcc-patches@gcc.gnu.org'.

Cc: Eric Gallager <egall@gwmail.gwu.edu>
Signed-off-by: Alejandro Colomar <alx@kernel.org>
---

Hi!

v2 changes:

-  Fix comment.  [Eric]

Cheers,
Alex


Range-diff against v1:
1:  0ee3f802637 ! 1:  2bd0e0f82bf contrib/: Configure git-format-patch(1) to add To: gcc-patches@gcc.gnu.org
    @@ Commit message
                 * gcc-git-customization.sh: Configure git-format-patch(1) to add
                 'To: gcc-patches@gcc.gnu.org'.
     
    +    Cc: Eric Gallager <egall@gwmail.gwu.edu>
         Signed-off-by: Alejandro Colomar <alx@kernel.org>
     
      ## contrib/gcc-git-customization.sh ##
    -@@ contrib/gcc-git-customization.sh: git config diff.md.xfuncname '^\(define.*$'
    +@@ contrib/gcc-git-customization.sh: git config alias.gcc-style '!f() {
    + # *.md    diff=md
    + git config diff.md.xfuncname '^\(define.*$'
      
    - # Tell git send-email where patches go.
    +-# Tell git send-email where patches go.
    ++# Tell git-format-patch(1)/git-send-email(1) where patches go.
      # ??? Maybe also set sendemail.tocmd to guess from MAINTAINERS?
     +git config format.to 'gcc-patches@gcc.gnu.org'
      git config sendemail.to 'gcc-patches@gcc.gnu.org'

 contrib/gcc-git-customization.sh | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

Comments

Alejandro Colomar Oct. 17, 2024, 2:57 p.m. UTC | #1
On Thu, Oct 17, 2024 at 04:54:04PM GMT, Alejandro Colomar wrote:
> Just like we already do for git-send-email(1).  In some cases, patches
> are prepared with git-format-patch(1), but are sent with a different
> program, or some flags to git-send-email(1) may accidentally inhibit the
> configuration.  By adding the TO in the email file, we make sure that
> gcc-patches@ will receive the patch.
> 
> contrib/ChangeLog:
> 
> 	* gcc-git-customization.sh: Configure git-format-patch(1) to add
> 	'To: gcc-patches@gcc.gnu.org'.
> 
> Cc: Eric Gallager <egall@gwmail.gwu.edu>
> Signed-off-by: Alejandro Colomar <alx@kernel.org>
> ---
> 
> Hi!
> 
> v2 changes:
> 
> -  Fix comment.  [Eric]
> 
> Cheers,
> Alex

BTW, this patch will need
<https://inbox.sourceware.org/gcc-patches/eac2d18d8a0462f028fd69d35cd705931e5b4b42.1729080460.git.alx@kernel.org/T/#u>
to be applied first, to allow the Cc: tag.  Please apply it too.  :)

Have a lovely day!
Alex

> 
> 
> Range-diff against v1:
> 1:  0ee3f802637 ! 1:  2bd0e0f82bf contrib/: Configure git-format-patch(1) to add To: gcc-patches@gcc.gnu.org
>     @@ Commit message
>                  * gcc-git-customization.sh: Configure git-format-patch(1) to add
>                  'To: gcc-patches@gcc.gnu.org'.
>      
>     +    Cc: Eric Gallager <egall@gwmail.gwu.edu>
>          Signed-off-by: Alejandro Colomar <alx@kernel.org>
>      
>       ## contrib/gcc-git-customization.sh ##
>     -@@ contrib/gcc-git-customization.sh: git config diff.md.xfuncname '^\(define.*$'
>     +@@ contrib/gcc-git-customization.sh: git config alias.gcc-style '!f() {
>     + # *.md    diff=md
>     + git config diff.md.xfuncname '^\(define.*$'
>       
>     - # Tell git send-email where patches go.
>     +-# Tell git send-email where patches go.
>     ++# Tell git-format-patch(1)/git-send-email(1) where patches go.
>       # ??? Maybe also set sendemail.tocmd to guess from MAINTAINERS?
>      +git config format.to 'gcc-patches@gcc.gnu.org'
>       git config sendemail.to 'gcc-patches@gcc.gnu.org'
> 
>  contrib/gcc-git-customization.sh | 3 ++-
>  1 file changed, 2 insertions(+), 1 deletion(-)
> 
> diff --git a/contrib/gcc-git-customization.sh b/contrib/gcc-git-customization.sh
> index 54bd35ea1aa..dd59bece1dc 100755
> --- a/contrib/gcc-git-customization.sh
> +++ b/contrib/gcc-git-customization.sh
> @@ -41,8 +41,9 @@ git config alias.gcc-style '!f() {
>  # *.md    diff=md
>  git config diff.md.xfuncname '^\(define.*$'
>  
> -# Tell git send-email where patches go.
> +# Tell git-format-patch(1)/git-send-email(1) where patches go.
>  # ??? Maybe also set sendemail.tocmd to guess from MAINTAINERS?
> +git config format.to 'gcc-patches@gcc.gnu.org'
>  git config sendemail.to 'gcc-patches@gcc.gnu.org'
>  
>  set_user=$(git config --get "user.name")
> -- 
> 2.45.2
>
Eric Gallager Oct. 17, 2024, 7:20 p.m. UTC | #2
On Thu, Oct 17, 2024 at 10:54 AM Alejandro Colomar <alx@kernel.org> wrote:
>
> Just like we already do for git-send-email(1).  In some cases, patches
> are prepared with git-format-patch(1), but are sent with a different
> program, or some flags to git-send-email(1) may accidentally inhibit the
> configuration.  By adding the TO in the email file, we make sure that
> gcc-patches@ will receive the patch.
>
> contrib/ChangeLog:
>
>         * gcc-git-customization.sh: Configure git-format-patch(1) to add
>         'To: gcc-patches@gcc.gnu.org'.
>
> Cc: Eric Gallager <egall@gwmail.gwu.edu>
> Signed-off-by: Alejandro Colomar <alx@kernel.org>
> ---
>
> Hi!
>
> v2 changes:
>
> -  Fix comment.  [Eric]
>
> Cheers,
> Alex
>
>
> Range-diff against v1:
> 1:  0ee3f802637 ! 1:  2bd0e0f82bf contrib/: Configure git-format-patch(1) to add To: gcc-patches@gcc.gnu.org
>     @@ Commit message
>                  * gcc-git-customization.sh: Configure git-format-patch(1) to add
>                  'To: gcc-patches@gcc.gnu.org'.
>
>     +    Cc: Eric Gallager <egall@gwmail.gwu.edu>
>          Signed-off-by: Alejandro Colomar <alx@kernel.org>
>
>       ## contrib/gcc-git-customization.sh ##
>     -@@ contrib/gcc-git-customization.sh: git config diff.md.xfuncname '^\(define.*$'
>     +@@ contrib/gcc-git-customization.sh: git config alias.gcc-style '!f() {
>     + # *.md    diff=md
>     + git config diff.md.xfuncname '^\(define.*$'
>
>     - # Tell git send-email where patches go.
>     +-# Tell git send-email where patches go.
>     ++# Tell git-format-patch(1)/git-send-email(1) where patches go.
>       # ??? Maybe also set sendemail.tocmd to guess from MAINTAINERS?
>      +git config format.to 'gcc-patches@gcc.gnu.org'
>       git config sendemail.to 'gcc-patches@gcc.gnu.org'
>
>  contrib/gcc-git-customization.sh | 3 ++-
>  1 file changed, 2 insertions(+), 1 deletion(-)
>
> diff --git a/contrib/gcc-git-customization.sh b/contrib/gcc-git-customization.sh
> index 54bd35ea1aa..dd59bece1dc 100755
> --- a/contrib/gcc-git-customization.sh
> +++ b/contrib/gcc-git-customization.sh
> @@ -41,8 +41,9 @@ git config alias.gcc-style '!f() {
>  # *.md    diff=md
>  git config diff.md.xfuncname '^\(define.*$'
>
> -# Tell git send-email where patches go.
> +# Tell git-format-patch(1)/git-send-email(1) where patches go.
>  # ??? Maybe also set sendemail.tocmd to guess from MAINTAINERS?
> +git config format.to 'gcc-patches@gcc.gnu.org'
>  git config sendemail.to 'gcc-patches@gcc.gnu.org'
>
>  set_user=$(git config --get "user.name")
> --
> 2.45.2
>

LGTM, but my approval doesn't actually mean anything, so...
diff mbox series

Patch

diff --git a/contrib/gcc-git-customization.sh b/contrib/gcc-git-customization.sh
index 54bd35ea1aa..dd59bece1dc 100755
--- a/contrib/gcc-git-customization.sh
+++ b/contrib/gcc-git-customization.sh
@@ -41,8 +41,9 @@  git config alias.gcc-style '!f() {
 # *.md    diff=md
 git config diff.md.xfuncname '^\(define.*$'
 
 # Tell git send-email where patches go.
 # ??? Maybe also set sendemail.tocmd to guess from MAINTAINERS?
+git config format.to 'gcc-patches@gcc.gnu.org'
 git config sendemail.to 'gcc-patches@gcc.gnu.org'
 
 set_user=$(git config --get "user.name")
@@ -41,8 +41,9 @@  git config alias.gcc-style '!f() {
 git config diff.md.xfuncname '^\(define.*$'
 
-# Tell git send-email where patches go.
+# Tell git-format-patch(1)/git-send-email(1) where patches go.
 # ??? Maybe also set sendemail.tocmd to guess from MAINTAINERS?